@@ -18,7 +18,7 @@
  *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  *  Boston, MA  02111-1307  USA
  *
- *  $Id: uim-tomoe-gtk.c,v 1.13 2006/11/28 04:26:46 makeinu Exp $
+ *  $Id: uim-tomoe-gtk.c,v 1.14 2006/12/06 06:48:57 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -84,18 +84,12 @@ check_helper_connection (void)
 /*
  *  main
  */
-static void
-quit (void)
-{
-    gtk_exit (0);
-}
-
 int
 main (int argc, char *argv[])
 {
     GtkWidget *window;
     TomoeWindow *tomoe;
-    TomoeStrokeSearch *page;
+    TomoeHandwriting *page;
 
     setlocale (LC_ALL, "");
     bindtextdomain (PACKAGE, LOCALEDIR);
@@ -110,16 +104,14 @@ main (int argc, char *argv[])
     window = tomoe_window_new ();
     gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
     gtk_widget_show (window);
-    g_signal_connect (G_OBJECT (window), "response",
-                      G_CALLBACK (gtk_main_quit), NULL);
     g_signal_connect (GTK_OBJECT (window), "destroy",
-                      G_CALLBACK (quit), NULL);
+                      G_CALLBACK (gtk_main_quit), NULL);
 
 
     /* add hooks */
     tomoe = TOMOE_WINDOW (window);
-    page = TOMOE_STROKE_SEARCH (tomoe_window_get_handwriting_page (tomoe));
-    g_signal_connect (G_OBJECT (tomoe_stroke_search_get_candidates_view (page)),
+    page = TOMOE_HANDWRITING (tomoe_window_get_handwriting_page (tomoe));
+    g_signal_connect (G_OBJECT (tomoe_handwriting_get_char_table (page)),
                       "selected",
                       G_CALLBACK (char_clicked_cb),
                       (gpointer) tomoe);
